#ifndef __client_menu_h
#define __client_menu_h

@class InputLine;
@extern InputLine *input_active;

#endif
